summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/video/cps1.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/video/cps1.cpp')
-rw-r--r--src/mame/video/cps1.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/mame/video/cps1.cpp b/src/mame/video/cps1.cpp
index ec672063d97..fc438ea482e 100644
--- a/src/mame/video/cps1.cpp
+++ b/src/mame/video/cps1.cpp
@@ -2194,14 +2194,14 @@ TILE_GET_INFO_MEMBER(cps_state::get_tile0_info)
should alternate between the left and right side of the 16x16 tiles */
gfxset = (tile_index & 0x20) >> 5;
- SET_TILE_INFO_MEMBER(gfxset,
+ tileinfo.set(gfxset,
code,
(attr & 0x1f) + 0x20,
TILE_FLIPYX((attr & 0x60) >> 5));
tileinfo.group = (attr & 0x0180) >> 7;
// for out of range tiles, switch to fully transparent data
// (but still call SET_TILE_INFO_MEMBER, otherwise problems might occur on boot e.g. unsquad)
if (code == -1)
tileinfo.pen_data = m_empty_tile;
}
@@ -2213,7 +2213,7 @@ TILE_GET_INFO_MEMBER(cps_state::get_tile1_info)
code = gfxrom_bank_mapper(GFXTYPE_SCROLL2, code);
- SET_TILE_INFO_MEMBER(2,
+ tileinfo.set(2,
code,
(attr & 0x1f) + 0x40,
TILE_FLIPYX((attr & 0x60) >> 5));
@@ -2231,14 +2231,14 @@ TILE_GET_INFO_MEMBER(cps_state::get_tile2_info)
code = gfxrom_bank_mapper(GFXTYPE_SCROLL3, code);
- SET_TILE_INFO_MEMBER(3,
+ tileinfo.set(3,
code,
(attr & 0x1f) + 0x60,
TILE_FLIPYX((attr & 0x60) >> 5));
tileinfo.group = (attr & 0x0180) >> 7;
// for out of range tiles, switch to fully transparent data
// (but still call SET_TILE_INFO_MEMBER, otherwise problems might occur on boot e.g. unsquad)
if (code == -1)
tileinfo.pen_data = m_empty_tile;
}
@@ -2194,14 +2194,14 @@ TILE_GET_INFO_MEMBER(cps_state::get_tile0_info)
tileinfo.group = (attr & 0x0180) >> 7;
// for out of range tiles, switch to fully transparent data
- // (but still call SET_TILE_INFO_MEMBER, otherwise problems might occur on boot e.g. unsquad)
+ // (but still call tileinfo.set, otherwise problems might occur on boot e.g. unsquad)
if (code == -1)
tileinfo.pen_data = m_empty_tile;
@@ -2231,14 +2231,14 @@ TILE_GET_INFO_MEMBER(cps_state::get_tile2_info)
tileinfo.group = (attr & 0x0180) >> 7;
// for out of range tiles, switch to fully transparent data
- // (but still call SET_TILE_INFO_MEMBER, otherwise problems might occur on boot e.g. unsquad)
+ // (but still call tileinfo.set, otherwise problems might occur on boot e.g. unsquad)
if (code == -1)
tileinfo.pen_data = m_empty_tile;